const express = require('express');
const { DynamoDBClient } = require('@aws-sdk/client-dynamodb');
const { DynamoDBDocumentClient, QueryCommand } = require('@aws-sdk/lib-dynamodb');
const router = express.Router();

// Configuration DynamoDB
const dbClient = new DynamoDBClient({ region: 'us-east-1' });
const ddb = DynamoDBDocumentClient.from(dbClient);
const IMAGES_TABLE = 'Images';

// Page d'accueil avec l'album de l'utilisateur
router.get('/home', async (req, res) => {
    const { username } = req.query;

    if (!username) {
        return res.redirect('/');
    }

    try {
        // Récupérer les images de l'utilisateur
        const data = await ddb.send(new QueryCommand({
            TableName: IMAGES_TABLE,
            KeyConditionExpression: 'username = :username',
            ExpressionAttributeValues: {
                ':username': username,
            },
        }));

        res.render('home', {
            username,
            images: data.Items || [], // Images ou tableau vide si aucune image
        });
    } catch (err) {
        console.error(err);
        res.render('home', {
            username,
            images: [],
            error: 'Erreur lors de la récupération des images',
        });
    }
});

module.exports = router;
